/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package com.evasion.springsecurity;

import com.evasion.ejb.local.UserAuthServiceLocal;
import com.evasion.entity.security.User;
import java.util.Date;
import javax.ejb.EJB;
import javax.faces.context.FacesContext;
import javax.servlet.http.HttpServletRequest;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.ApplicationEvent;
import org.springframework.context.ApplicationListener;
import org.springframework.security.event.authentication.AbstractAuthenticationEvent;
import org.springframework.security.event.authentication.AbstractAuthenticationFailureEvent;
import org.springframework.security.event.authentication.AuthenticationSuccessEvent;
import org.springframework.stereotype.Repository;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

/**
 *
 * @author sebastien
 */
@Repository("securityListener")
public class SecurityListener implements ApplicationListener {

    @EJB
    UserAuthServiceLocal userAuthService;
    /**
     * LOGGER.
     */
    private static final Logger LOGGER = LoggerFactory.getLogger(SecurityListener.class);

    // getter and setter ...
    @Override
    public void onApplicationEvent(ApplicationEvent event) {
        if (event instanceof AbstractAuthenticationEvent) {

            if (event instanceof AbstractAuthenticationFailureEvent) {
                LOGGER.warn("Erreur d'authentification: {}", new Object[]{event});
            }

            if (event instanceof AuthenticationSuccessEvent) {
                AuthenticationSuccessEvent authenticationSuccessEvent = (AuthenticationSuccessEvent) event;
                String username = authenticationSuccessEvent.getAuthentication().getName();
                User user = userAuthService.findUserByUserName(username);
                // sauvergarde en session de la précédente date de connexion
                HttpServletRequest request = (HttpServletRequest) ( (ServletRequestAttributes) RequestContextHolder.getRequestAttributes() ).getRequest();
                request.getSession().setAttribute("lastLogin", user.getLastLogin());
                // mise à jour de la date de connexion.
                userAuthService.updateLastLogin(user.getUsername());
                LOGGER.debug("Validation de l'authentification et mise à jour de la date de dernière connection");
            }

        }
    }

    public void setUserAuthService(UserAuthServiceLocal userAuthService) {
        this.userAuthService = userAuthService;
    }
}
